@@ -1,12 +1,12 @@
 /**
  * \file pcm/pcm_empty.c
  * \ingroup PCM_Plugins
- * \brief PCM Null Plugin Interface
+ * \brief PCM Empty Plugin Interface
  * \author Jaroslav Kysela <perex@perex.cz>
  * \date 2006
  */
 /*
- *  PCM - Null plugin
+ *  PCM - Empty plugin
  *  Copyright (c) 2006 by Jaroslav Kysela <perex@perex.cz>
  *
  *
@@ -25,7 +25,7 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-  
+
 #include "pcm_local.h"
 #include "pcm_plugin.h"
 
@@ -36,21 +36,26 @@ const char *_snd_module_pcm_empty = "";
 
 /*! \page pcm_plugins
 
-\section pcm_plugins_null Plugin: Null
+\section pcm_plugins_empty Plugin: Empty
 
-This plugin discards contents of a PCM stream or creates a stream with zero
-samples.
-
-Note: This implementation uses devices /dev/null (playback, must be writable)
-and /dev/full (capture, must be readable).
+This plugin just redirects the PCM stream to another plugin.
 
 \code
 pcm.name {
-        type null               # Null PCM
+	type empty               # Null PCM
+	slave STR               # Slave name
+	# or
+	slave {                 # Slave definition
+		pcm STR         # Slave PCM name
+		# or
+		pcm { }         # Slave PCM definition
+		[format STR]    # Slave format
+		[channels INT]  # Slave channels
+	}
 }
 \endcode
 
-\subsection pcm_plugins_null_funcref Function reference
+\subsection pcm_plugins_empty_funcref Function reference
 
 <UL>
   <LI>_snd_pcm_empty_open()
@@ -72,8 +77,8 @@ pcm.name {
  *          changed in future.
  */
 int _snd_pcm_empty_open(snd_pcm_t **pcmp, const char *name ATTRIBUTE_UNUSED,
-		        snd_config_t *root, snd_config_t *conf, 
-		        snd_pcm_stream_t stream, int mode)
+			snd_config_t *root, snd_config_t *conf,
+			snd_pcm_stream_t stream, int mode)
 {
 	snd_config_t *slave = NULL, *sconf;
 	snd_config_iterator_t i, next;
@@ -90,11 +95,11 @@ int _snd_pcm_empty_open(snd_pcm_t **pcmp, const char *name ATTRIBUTE_UNUSED,
 			slave = n;
 			continue;
 		}
-		SNDERR("Unknown field %s", id);
+		snd_error(PCM, "Unknown field %s", id);
 		return -EINVAL;
 	}
 	if (!slave) {
-		SNDERR("slave is not defined");
+		snd_error(PCM, "slave is not defined");
 		return -EINVAL;
 	}
 	err = snd_pcm_slave_conf(root, slave, &sconf, 0);
