@@ -18,16 +18,16 @@
  *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-  
+
 #include "pcm_generic.h"
 
 typedef snd_pcm_uframes_t (*snd_pcm_slave_xfer_areas_func_t)
-     (snd_pcm_t *pcm, 
+     (snd_pcm_t *pcm,
       const snd_pcm_channel_area_t *areas,
-      snd_pcm_uframes_t offset, 
+      snd_pcm_uframes_t offset,
       snd_pcm_uframes_t size,
       const snd_pcm_channel_area_t *slave_areas,
-      snd_pcm_uframes_t slave_offset, 
+      snd_pcm_uframes_t slave_offset,
       snd_pcm_uframes_t *slave_sizep);
 
 typedef snd_pcm_sframes_t (*snd_pcm_slave_xfer_areas_undo_func_t)
@@ -45,11 +45,13 @@ typedef struct {
 	snd_pcm_slave_xfer_areas_undo_func_t undo_write;
 	int (*init)(snd_pcm_t *pcm);
 	snd_pcm_uframes_t appl_ptr, hw_ptr;
-} snd_pcm_plugin_t;	
+} snd_pcm_plugin_t;
 
 /* make local functions really local */
 #define snd_pcm_plugin_init \
 	snd1_pcm_plugin_init
+#define snd_pcm_plugin_may_wait_for_avail_min_conv \
+	snd1_pcm_plugin_may_wait_for_avail_min_conv
 #define snd_pcm_plugin_may_wait_for_avail_min \
 	snd1_pcm_plugin_may_wait_for_avail_min
 #define snd_pcm_plugin_fast_ops \
@@ -66,6 +68,8 @@ typedef struct {
 void snd_pcm_plugin_init(snd_pcm_plugin_t *plugin);
 snd_pcm_sframes_t snd_pcm_plugin_rewind(snd_pcm_t *pcm, snd_pcm_uframes_t frames);
 snd_pcm_sframes_t snd_pcm_plugin_forward(snd_pcm_t *pcm, snd_pcm_uframes_t frames);
+int snd_pcm_plugin_may_wait_for_avail_min_conv(snd_pcm_t *pcm, snd_pcm_uframes_t avail,
+					       snd_pcm_uframes_t (*conv)(snd_pcm_t *, snd_pcm_uframes_t));
 int snd_pcm_plugin_may_wait_for_avail_min(snd_pcm_t *pcm, snd_pcm_uframes_t avail);
 
 extern const snd_pcm_fast_ops_t snd_pcm_plugin_fast_ops;
