@@ -21,10 +21,11 @@
  *
  *   You should have received a copy of the GNU Lesser General Public
  *   License along with this library; if not, write to the Free Software
- *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA
+ *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
  *
  */
-  
+
+#include "local.h"
 #include <stdio.h>
 #include <stdlib.h>
 #include <stddef.h>
@@ -37,7 +38,6 @@
 #include <sys/ioctl.h>
 #include <net/if.h>
 #include <netdb.h>
-#include "local.h"
 
 #ifndef DOC_HIDDEN
 int snd_send_fd(int sock, void *data, size_t len, int fd)
@@ -60,14 +60,14 @@ int snd_send_fd(int sock, void *data, size_t len, int fd)
 	msghdr.msg_name = NULL;
 	msghdr.msg_namelen = 0;
 	msghdr.msg_iov = &vec;
- 	msghdr.msg_iovlen = 1;
+	msghdr.msg_iovlen = 1;
 	msghdr.msg_control = cmsg;
 	msghdr.msg_controllen = cmsg_len;
 	msghdr.msg_flags = 0;
 
 	ret = sendmsg(sock, &msghdr, 0 );
 	if (ret < 0) {
-		SYSERR("sendmsg failed");
+		snd_errornum(CORE, "sendmsg failed");
 		return -errno;
 	}
 	return ret;
@@ -100,7 +100,7 @@ int snd_receive_fd(int sock, void *data, size_t len, int *fd)
 
 	ret = recvmsg(sock, &msghdr, 0);
 	if (ret < 0) {
-		SYSERR("recvmsg failed");
+		snd_errornum(CORE, "recvmsg failed");
 		return -errno;
 	}
 	*fd = *fds;
