@@ -13,11 +13,10 @@
   GNU Lesser General Public License for more details.
 
   Authors: Mengdong Lin <mengdong.lin@intel.com>
-           Yao Jin <yao.jin@intel.com>
-           Liam Girdwood <liam.r.girdwood@linux.intel.com>
+	   Yao Jin <yao.jin@intel.com>
+	   Liam Girdwood <liam.r.girdwood@linux.intel.com>
 */
 
-#include "list.h"
 #include "tplg_local.h"
 
 /* mapping of kcontrol text names to types */
@@ -45,7 +44,7 @@ static int lookup_ops(const char *c)
 	/* cant find string name in our table so we use its ID number */
 	i = safe_strtol(c, &ret);
 	if (i < 0) {
-		SNDERR("wrong kcontrol ops value string '%s'", c);
+		snd_error(TOPOLOGY, "wrong kcontrol ops value string '%s'", c);
 		return i;
 	}
 
@@ -92,6 +91,8 @@ int tplg_parse_ops(snd_tplg_t *tplg ATTRIBUTE_UNUSED, snd_config_t *cfg,
 			if (snd_config_get_string(n, &value) < 0)
 				continue;
 			ival = lookup_ops(value);
+			if (ival < 0)
+				return ival;
 		} else {
 			if (tplg_get_integer(n, &ival, 0))
 				continue;
@@ -177,6 +178,8 @@ int tplg_parse_ext_ops(snd_tplg_t *tplg ATTRIBUTE_UNUSED,
 			if (snd_config_get_string(n, &value) < 0)
 				continue;
 			ival = lookup_ops(value);
+			if (ival < 0)
+				return ival;
 		} else {
 			if (tplg_get_integer(n, &ival, 0))
 				continue;
