@@ -183,7 +183,7 @@ static int parse_args(char ***argv, int argc, const char *cmd)
  */
 int uc_mgr_exec(const char *prog)
 {
-	pid_t p, f, maxfd;
+	pid_t p, f;
 	int err = 0, status;
 	char bin[PATH_MAX];
 	struct sigaction sa;
@@ -212,8 +212,6 @@ int uc_mgr_exec(const char *prog)
 		prog = bin;
 	}
 
-	maxfd = sysconf(_SC_OPEN_MAX);
-
 	/*
 	 * block SIGCHLD signal
 	 * ignore SIGINT and SIGQUIT in parent
@@ -259,11 +257,14 @@ int uc_mgr_exec(const char *prog)
 
 		close(f);
 
-#if defined(_GNU_SOURCE)
-		close_range(3, maxfd, 0);
+#if HAVE_DECL_CLOSEFROM
+		closefrom(3);
 #else
-		for (f = 3; f < maxfd; f++)
-			close(f);
+		{
+			pid_t maxfd = sysconf(_SC_OPEN_MAX);
+			for (f = 3; f < maxfd; f++)
+				close(f);
+		}
 #endif
 
 		/* install default handlers for the forked process */
